@@ -187,7 +187,7 @@ def git_pull_request(target_remote=None, target_branch=None,
                      rebase=True,
                      force_editor=False,
                      download=None,
-                     ignore_tag=False,
+                     tag_previous_revision=False,
                      dont_fork=True):
     branch = git_get_branch_name()
     if not branch:
@@ -257,7 +257,8 @@ def git_pull_request(target_remote=None, target_branch=None,
         fork_and_push_pull_request(g, repo, rebase, target_remote,
                                    target_branch, branch, user, title, message,
                                    comment_on_update, comment,
-                                   force_editor, ignore_tag, dont_fork)
+                                   force_editor, tag_previous_revision,
+                                   dont_fork)
 
 
 def download_pull_request(g, repo, target_remote, pull_number):
@@ -277,7 +278,7 @@ def download_pull_request(g, repo, target_remote, pull_number):
 
 
 def edit_file_get_content_and_remove(filename):
-    editor = os.getenv("EDITOR")
+    editor = _run_shell_command(["git", "var", "GIT_EDITOR"], output=True)
     if not editor:
         LOG.warning(
             "$EDITOR is unset, you will not be able to edit the "
@@ -308,6 +309,7 @@ def find_pull_request_template():
 
 def get_pr_template_message(template):
     fd, bodyfilename = tempfile.mkstemp()
+    os.close(fd)
     shutil.copy(template, bodyfilename)
     content = edit_file_get_content_and_remove(bodyfilename)
 
@@ -316,6 +318,7 @@ def get_pr_template_message(template):
 
 def edit_title_and_message(title, message):
     fd, bodyfilename = tempfile.mkstemp()
+    os.close(fd)
     with open(bodyfilename, "w") as body:
         body.write(title + "\n\n")
         body.write(message + "\n")
@@ -340,12 +343,13 @@ def preserve_older_revision(branch, remote_to_push):
 def fork_and_push_pull_request(g, repo_to_fork, rebase, target_remote,
                                target_branch, branch, user, title, message,
                                comment_on_update, comment,
-                               force_editor, ignore_tag, dont_fork):
+                               force_editor, tag_previous_revision, dont_fork):
 
     g_user = g.get_user()
 
     if dont_fork:
         remote_to_push = target_remote
+        head = "{}:{}".format(repo_to_fork.owner.login, branch)
     else:
         repo_forked = g_user.create_fork(repo_to_fork)
         LOG.info("Forked repository: %s", repo_forked.html_url)
@@ -361,6 +365,7 @@ def fork_and_push_pull_request(g, repo_to_fork, rebase, target_remote,
                 ["git", "remote", "add",
                  remote_to_push, repo_forked.clone_url])
             LOG.info("Added forked repository as remote `%s'", remote_to_push)
+        head = "{}:{}".format(user, branch)
 
     if rebase:
         _run_shell_command(["git", "remote", "update", target_remote])
@@ -440,7 +445,7 @@ def fork_and_push_pull_request(g, repo_to_fork, rebase, target_remote,
 
         try:
             pull = repo_to_fork.create_pull(base=target_branch,
-                                            head=user + ":" + branch,
+                                            head=head,
                                             title=title,
                                             body=message)
         except github.GithubException as e:
@@ -451,14 +456,14 @@ def fork_and_push_pull_request(g, repo_to_fork, rebase, target_remote,
         else:
             LOG.info("Pull-request created: %s", pull.html_url)
 
-    if not ignore_tag:
+    if tag_previous_revision:
         preserve_older_revision(branch, remote_to_push)
 
 
 def _format_github_exception(action, exc):
     url = exc.data.get("documentation_url", "GitHub documentation")
-    errors_msg = "\n".join(map(operator.itemgetter("message"),
-                               exc.data.get("errors", [])))
+    errors_msg = "\n".join(error.get("message", "")
+                           for error in exc.data.get("errors", []))
     return (
         "Unable to %s: %s (%s)\n"
         "%s\n"
@@ -506,7 +511,7 @@ def main():
         help="Comment to publish when updating the pull-request"
     )
     parser.add_argument(
-        "--no-tag-previous-revision",
+        "--tag-previous-revision",
         action="store_true",
         default=False,
         help="Preserve older revision when pushing"
@@ -540,7 +545,7 @@ def main():
             rebase=not args.no_rebase,
             force_editor=args.force_editor,
             download=args.download,
-            ignore_tag=args.no_tag_previous_revision,
+            tag_previous_revision=args.tag_previous_revision,
             dont_fork=args.no_fork
         )
     except Exception:
